@@ -16,9 +16,9 @@ class ConsolidationType(str, Enum):
 
 
 class ConsolidateParameters(FormatterParameters):
-    type: ConsolidationType = Field(ConsolidationType.unknown, description="""Type of consolidation, use
-    - *linker* to retain only known entities
-    - *unkown* to retain all but prepending `unknown_` to the label name of unknwon entities
+    type: ConsolidationType = Field(ConsolidationType.unknown, description="""Type of consolidation, use\
+    - *linker* to retain only known entities\
+    - *unkown* to retain all but prepending `unknown_` to the label name of unknwon entities\
     - *unkown_only* to retain only unknown entities prepending `unknown_` to their label name""")
 
 
